#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_TEN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_TEN_HPP_INCLUDED

#include <boost/simd/constant/include/constants/ten.hpp>

#endif
